==> cds-feature-ucl-3.8.0-sources.jar: com/sap/cds/feature/ucl/services/AssignEventContext.java <==
package com.sap.cds.feature.ucl.services;

import com.sap.cds.services.EventContext;
import com.sap.cds.services.EventName;

@EventName(UclService.EVENT_ASSIGN)
public interface AssignEventContext extends EventContext {

	/**
	 * Creates an {@link EventContext} already overlayed with this interface. The event is set to be
	 * {@link UclService#EVENT_ASSIGN}
	 * @return the {@link AssignEventContext}
	 */
	static AssignEventContext create() {
		return EventContext.create(AssignEventContext.class, null);
	}

	@Override
	UclService getService();

	/**
	 * @return the tenant ID
	 */
	String getTenant();

	/**
	 * Sets the tenant ID
	 *
	 * @param tenant the tenant ID
	 */
	void setTenant(String tenant);

	/**
	 * Returns the `context` node of the payload provided by UCL which includes metadata of the formation assignment notification.
	 * @return the `context` node of the payload
	 */
	SpiiContext getUclContext();

	/**
	 * Sets the `context` node of the formation assignment notification.
	 *
	 * @param spiiContext the `context` node
	 */
	void setUclContext(SpiiContext spiiContext);

	/**
	 * Returns an instance {@link SpiiTenant} representing the assigned tenant of the formation assignment notification.
	 * @return the assigned tenant
	 */
	SpiiTenant getUclAssignedTenant();

	/**
	 * Sets the assigned tenant of the formation assignment notification.
	 * @param uclAssignedTenant the assigned tenant
	 */
	void setUclAssignedTenant(SpiiTenant uclAssignedTenant);

	/**
	 * Returns an instance {@link SpiiTenant} representing the receiver tenant of the formation assignment notification.
	 * @return the assigned tenant
	 */
	SpiiTenant getUclReceiverTenant();

	/**
	 * Sets the receiver tenant of the formation assignment notification.
	 * @param uclReceiverTenant the receiver tenant
	 */
	void setUclReceiverTenant(SpiiTenant uclReceiverTenant);

	SpiiResult getUclResult();

	void setUclResult(SpiiResult uclResult);

}

==> cds-feature-ucl-3.9.0-sources.jar: com/sap/cds/feature/ucl/services/AssignEventContext.java <==
package com.sap.cds.feature.ucl.services;

import com.sap.cds.ql.CdsName;
import com.sap.cds.services.EventContext;
import com.sap.cds.services.EventName;

@EventName(UclService.EVENT_ASSIGN)
public interface AssignEventContext extends EventContext {

	/**
	 * Creates an {@link EventContext} already overlayed with this interface. The event is set to be
	 * {@link UclService#EVENT_ASSIGN}
	 * @return the {@link AssignEventContext}
	 */
	static AssignEventContext create() {
		return EventContext.create(AssignEventContext.class, null);
	}

	@Override
	UclService getService();

	/**
	 * @return the tenant ID
	 */
	String getTenant();

	/**
	 * Sets the tenant ID
	 *
	 * @param tenant the tenant ID
	 */
	void setTenant(String tenant);

	/**
	 * Returns the `context` node of the payload provided by UCL which includes metadata of the formation assignment notification.
	 * @return the `context` node of the payload
	 */
	SpiiContext getUclContext();

	/**
	 * Sets the `context` node of the formation assignment notification.
	 *
	 * @param spiiContext the `context` node
	 */
	void setUclContext(SpiiContext spiiContext);

	/**
	 * Returns an instance {@link SpiiTenant} representing the assigned tenant of the formation assignment notification.
	 * @return the assigned tenant
	 */
	SpiiTenant getUclAssignedTenant();

	/**
	 * Sets the assigned tenant of the formation assignment notification.
	 * @param uclAssignedTenant the assigned tenant
	 */
	void setUclAssignedTenant(SpiiTenant uclAssignedTenant);

	/**
	 * Returns an instance {@link SpiiTenant} representing the receiver tenant of the formation assignment notification.
	 * @return the assigned tenant
	 */
	SpiiTenant getUclReceiverTenant();

	/**
	 * Sets the receiver tenant of the formation assignment notification.
	 * @param uclReceiverTenant the receiver tenant
	 */
	void setUclReceiverTenant(SpiiTenant uclReceiverTenant);

	@Deprecated(forRemoval = true)
	@CdsName("result")
	SpiiResult getUclResult();

	@Deprecated(forRemoval = true)
	@CdsName("result")
	void setUclResult(SpiiResult uclResult);

	/**
	 * @return The result to be returned to UCL for the given request.
	 */
	SpiiResult getResult();

	/**
	 * @param spiiResult The result to be returned to UCL for the given request.
	 */
	void setResult(SpiiResult spiiResult);

}
